# Long T5 benchmark

This dataset collection comprises the evaluation benchmark used in the paper:
_LongT5: Efficient Text-To-Text Transformer for Long Sequences_

LongT5 is an extension of the T5 model that handles long sequence inputs more
efficiently. LongT5 achieves state-of-the-art performance on several
summarization benchmarks that required longer context or multi-document
understanding.
